# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from goodmem_client.models.error_detail import ErrorDetail
from goodmem_client.models.memory import Memory
from typing import Optional, Set
from typing_extensions import Self

class BatchMemoryResult(BaseModel):
    """
    Individual item result for a batch memories operation
    """ # noqa: E501
    success: StrictBool = Field(description="Whether this individual operation succeeded")
    memory_id: Optional[StrictStr] = Field(default=None, description="Memory ID associated with this result (present for batchGet errors and batchDelete results)", alias="memoryId")
    memory: Optional[Memory] = None
    error: Optional[ErrorDetail] = None
    __properties: ClassVar[List[str]] = ["success", "memoryId", "memory", "error"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BatchMemoryResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of memory
        if self.memory:
            _dict['memory'] = self.memory.to_dict()
        # override the default output from pydantic by calling `to_dict()` of error
        if self.error:
            _dict['error'] = self.error.to_dict()
        # set to None if memory_id (nullable) is None
        # and model_fields_set contains the field
        if self.memory_id is None and "memory_id" in self.model_fields_set:
            _dict['memoryId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BatchMemoryResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "success": obj.get("success"),
            "memoryId": obj.get("memoryId"),
            "memory": Memory.from_dict(obj["memory"]) if obj.get("memory") is not None else None,
            "error": ErrorDetail.from_dict(obj["error"]) if obj.get("error") is not None else None
        })
        return _obj


