# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.models.admin_reload_license_response import AdminReloadLicenseResponse

class TestAdminReloadLicenseResponse(unittest.TestCase):
    """AdminReloadLicenseResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdminReloadLicenseResponse:
        """Test AdminReloadLicenseResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdminReloadLicenseResponse`
        """
        model = AdminReloadLicenseResponse()
        if include_optional:
            return AdminReloadLicenseResponse(
                status = '',
                message = '',
                active_license = goodmem_client.models.active_license_metadata.ActiveLicenseMetadata(
                    filename = '', 
                    sha256 = '', 
                    size_bytes = 56, 
                    modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return AdminReloadLicenseResponse(
        )
        """

    def testAdminReloadLicenseResponse(self):
        """Test AdminReloadLicenseResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
