# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from goodmem_client.models.api_key_auth import ApiKeyAuth
from goodmem_client.models.credential_kind import CredentialKind
from goodmem_client.models.gcp_adc_auth import GcpAdcAuth
from typing import Optional, Set
from typing_extensions import Self

class EndpointAuthentication(BaseModel):
    """
    Structured credential payload describing how GoodMem should authenticate with an upstream provider.
    """ # noqa: E501
    kind: CredentialKind
    api_key: Optional[ApiKeyAuth] = Field(default=None, alias="apiKey")
    gcp_adc: Optional[GcpAdcAuth] = Field(default=None, alias="gcpAdc")
    labels: Optional[Dict[str, StrictStr]] = Field(default=None, description="Optional annotations to aid operators (e.g., \"owner=vertex\")")
    __properties: ClassVar[List[str]] = ["kind", "apiKey", "gcpAdc", "labels"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EndpointAuthentication from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of api_key
        if self.api_key:
            _dict['apiKey'] = self.api_key.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gcp_adc
        if self.gcp_adc:
            _dict['gcpAdc'] = self.gcp_adc.to_dict()
        # set to None if labels (nullable) is None
        # and model_fields_set contains the field
        if self.labels is None and "labels" in self.model_fields_set:
            _dict['labels'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EndpointAuthentication from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "kind": obj.get("kind"),
            "apiKey": ApiKeyAuth.from_dict(obj["apiKey"]) if obj.get("apiKey") is not None else None,
            "gcpAdc": GcpAdcAuth.from_dict(obj["gcpAdc"]) if obj.get("gcpAdc") is not None else None,
            "labels": obj.get("labels")
        })
        return _obj


