# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.api.memories_api import MemoriesApi


class TestMemoriesApi(unittest.TestCase):
    """MemoriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MemoriesApi()

    def tearDown(self) -> None:
        pass

    def test_create_memory(self) -> None:
        """Test case for create_memory

        Create a new memory
        """
        pass

    def test_delete_memory(self) -> None:
        """Test case for delete_memory

        Delete a memory
        """
        pass

    def test_get_memory(self) -> None:
        """Test case for get_memory

        Get a memory by ID
        """
        pass

    def test_list_memories(self) -> None:
        """Test case for list_memories

        List memories in a space
        """
        pass


if __name__ == '__main__':
    unittest.main()
