# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.models.update_space_request import UpdateSpaceRequest

class TestUpdateSpaceRequest(unittest.TestCase):
    """UpdateSpaceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateSpaceRequest:
        """Test UpdateSpaceRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateSpaceRequest`
        """
        model = UpdateSpaceRequest()
        if include_optional:
            return UpdateSpaceRequest(
                validate_label_strategy = None,
                space_id = '550e8400-e29b-41d4-a716-446655440000',
                name = 'Updated Research Space',
                public_read = True,
                replace_labels = {"project": "Updated AI Research", "team": "NLP Group"},
                merge_labels = {"status": "active", "priority": "high"}
            )
        else:
            return UpdateSpaceRequest(
                space_id = '550e8400-e29b-41d4-a716-446655440000',
        )
        """

    def testUpdateSpaceRequest(self):
        """Test UpdateSpaceRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
