# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.models.memory import Memory

class TestMemory(unittest.TestCase):
    """Memory unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Memory:
        """Test Memory
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Memory`
        """
        model = Memory()
        if include_optional:
            return Memory(
                memory_id = '550e8400-e29b-41d4-a716-446655440000',
                space_id = '550e8400-e29b-41d4-a716-446655440001',
                original_content = 'This is the stored text content.',
                original_content_ref = 's3://my-bucket/document.pdf',
                content_type = 'text/plain',
                processing_status = 'COMPLETED',
                metadata = {"source": "document", "author": "John Doe"},
                created_at = 1672531200000,
                updated_at = 1672531200000,
                created_by_id = '550e8400-e29b-41d4-a716-446655440002',
                updated_by_id = '550e8400-e29b-41d4-a716-446655440002'
            )
        else:
            return Memory(
                memory_id = '550e8400-e29b-41d4-a716-446655440000',
                space_id = '550e8400-e29b-41d4-a716-446655440001',
                content_type = 'text/plain',
                processing_status = 'COMPLETED',
                created_at = 1672531200000,
                updated_at = 1672531200000,
                created_by_id = '550e8400-e29b-41d4-a716-446655440002',
                updated_by_id = '550e8400-e29b-41d4-a716-446655440002',
        )
        """

    def testMemory(self):
        """Test Memory"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
