# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.models.ocr_page import OcrPage

class TestOcrPage(unittest.TestCase):
    """OcrPage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OcrPage:
        """Test OcrPage
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OcrPage`
        """
        model = OcrPage()
        if include_optional:
            return OcrPage(
                raw_json = '[{"text":"Example"}]',
                markdown = '# Heading',
                layout = goodmem_client.models.ocr_layout.OcrLayout(
                    cells = [
                        goodmem_client.models.ocr_cell.OcrCell(
                            bbox = goodmem_client.models.bounding_box.BoundingBox(
                                x1 = 12.5, 
                                y1 = 34.7, 
                                x2 = 210.2, 
                                y2 = 98.3, ), 
                            category_label = 'section-header', 
                            category = 'UNSPECIFIED', 
                            text = 'Introduction', )
                        ], ),
                timings = goodmem_client.models.page_timings.PageTimings(
                    queue_wait_ms = 15, 
                    render_ms = 42, 
                    ocr_ms = 118, 
                    total_ms = 175, ),
                image = goodmem_client.models.image_info.ImageInfo(
                    width_px = 2150, 
                    height_px = 2575, 
                    dpi = 200, )
            )
        else:
            return OcrPage(
                layout = goodmem_client.models.ocr_layout.OcrLayout(
                    cells = [
                        goodmem_client.models.ocr_cell.OcrCell(
                            bbox = goodmem_client.models.bounding_box.BoundingBox(
                                x1 = 12.5, 
                                y1 = 34.7, 
                                x2 = 210.2, 
                                y2 = 98.3, ), 
                            category_label = 'section-header', 
                            category = 'UNSPECIFIED', 
                            text = 'Introduction', )
                        ], ),
                timings = goodmem_client.models.page_timings.PageTimings(
                    queue_wait_ms = 15, 
                    render_ms = 42, 
                    ocr_ms = 118, 
                    total_ms = 175, ),
                image = goodmem_client.models.image_info.ImageInfo(
                    width_px = 2150, 
                    height_px = 2575, 
                    dpi = 200, ),
        )
        """

    def testOcrPage(self):
        """Test OcrPage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
