# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.models.list_api_keys_response import ListApiKeysResponse

class TestListApiKeysResponse(unittest.TestCase):
    """ListApiKeysResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListApiKeysResponse:
        """Test ListApiKeysResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListApiKeysResponse`
        """
        model = ListApiKeysResponse()
        if include_optional:
            return ListApiKeysResponse(
                keys = [
                    goodmem_client.models.api_key_response.ApiKeyResponse(
                        api_key_id = '550e8400-e29b-41d4-a716-446655440000', 
                        user_id = 'b3303d0a-1a4a-493f-b9bf-38e37153b5a2', 
                        key_prefix = 'gm_12345...', 
                        status = 'ACTIVE', 
                        labels = {"purpose": "production", "service": "recommendation-engine"}, 
                        expires_at = 1672531200000, 
                        last_used_at = 1640995200000, 
                        created_at = 1640908800000, 
                        updated_at = 1640908800000, 
                        created_by_id = 'b3303d0a-1a4a-493f-b9bf-38e37153b5a2', 
                        updated_by_id = 'b3303d0a-1a4a-493f-b9bf-38e37153b5a2', )
                    ]
            )
        else:
            return ListApiKeysResponse(
        )
        """

    def testListApiKeysResponse(self):
        """Test ListApiKeysResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
