# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.models.recursive_chunking_configuration import RecursiveChunkingConfiguration

class TestRecursiveChunkingConfiguration(unittest.TestCase):
    """RecursiveChunkingConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RecursiveChunkingConfiguration:
        """Test RecursiveChunkingConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RecursiveChunkingConfiguration`
        """
        model = RecursiveChunkingConfiguration()
        if include_optional:
            return RecursiveChunkingConfiguration(
                chunk_size = 1000,
                chunk_overlap = 200,
                separators = ["\n\n", "\n", ".", " "],
                keep_strategy = 'KEEP_NONE',
                separator_is_regex = False,
                length_measurement = 'CHARACTER_COUNT'
            )
        else:
            return RecursiveChunkingConfiguration(
                chunk_size = 1000,
                chunk_overlap = 200,
                keep_strategy = 'KEEP_NONE',
                length_measurement = 'CHARACTER_COUNT',
        )
        """

    def testRecursiveChunkingConfiguration(self):
        """Test RecursiveChunkingConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
