# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.models.api_key_auth import ApiKeyAuth

class TestApiKeyAuth(unittest.TestCase):
    """ApiKeyAuth unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiKeyAuth:
        """Test ApiKeyAuth
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiKeyAuth`
        """
        model = ApiKeyAuth()
        if include_optional:
            return ApiKeyAuth(
                inline_secret = 'sk-1234567890abcdef',
                secret_ref = goodmem_client.models.secret_reference.SecretReference(
                    uri = 'vault://path/to/secret', 
                    hints = {
                        'key' : ''
                        }, ),
                header_name = 'Authorization',
                prefix = 'Bearer '
            )
        else:
            return ApiKeyAuth(
        )
        """

    def testApiKeyAuth(self):
        """Test ApiKeyAuth"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
