# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.models.system_init_response import SystemInitResponse

class TestSystemInitResponse(unittest.TestCase):
    """SystemInitResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SystemInitResponse:
        """Test SystemInitResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SystemInitResponse`
        """
        model = SystemInitResponse()
        if include_optional:
            return SystemInitResponse(
                already_initialized = True,
                message = 'System initialized successfully',
                root_api_key = 'goodmem_f923b5e6a07e4fb0bdcaa6b7d4c8fea1',
                user_id = '550e8400-e29b-41d4-a716-446655440000'
            )
        else:
            return SystemInitResponse(
                already_initialized = True,
                message = 'System initialized successfully',
        )
        """

    def testSystemInitResponse(self):
        """Test SystemInitResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
