# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301
import os

here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "goodmem-client"
VERSION = "1.5.10"
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support.",
    author="GoodMem API Support",
    author_email="support@goodmem.io",
    url="https://github.com/PAIR-Systems-Inc/goodmem",
    keywords=[
        "OpenAPI",
        "OpenAPI-Generator",
        "GoodMem API",
        "vector",
        "embeddings",
        "memory",
    ],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache 2.0",
    long_description_content_type="text/markdown",
    long_description=long_description,  # noqa: E501
    package_data={"goodmem_client": ["py.typed"]},
project_urls = {
        "Bug Reports": "https://github.com/PAIR-Systems-Inc/goodmem/issues",
        "Source": "https://github.com/PAIR-Systems-Inc/goodmem/tree/main/clients/python",
        "PyPI": "https://pypi.org/project/goodmem-client/",
    },classifiers = [
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],python_requires = PYTHON_REQUIRES,)