# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.models.embedder_response import EmbedderResponse

class TestEmbedderResponse(unittest.TestCase):
    """EmbedderResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EmbedderResponse:
        """Test EmbedderResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EmbedderResponse`
        """
        model = EmbedderResponse()
        if include_optional:
            return EmbedderResponse(
                embedder_id = '550e8400-e29b-41d4-a716-446655440000',
                display_name = 'OpenAI Ada-2',
                description = 'OpenAI's text embedding model with 1536 dimensions',
                provider_type = 'OPENAI',
                endpoint_url = 'https://api.openai.com/v1',
                api_path = '/embeddings',
                model_identifier = 'text-embedding-3-small',
                dimensionality = 1536,
                max_sequence_length = 8192,
                supported_modalities = [
                    'TEXT'
                    ],
                labels = {"environment": "production", "team": "nlp"},
                version = '1.0.0',
                monitoring_endpoint = 'https://monitoring.example.com/embedders/status',
                owner_id = '550e8400-e29b-41d4-a716-446655440000',
                created_at = 1617293472000,
                updated_at = 1617293472000,
                created_by_id = '550e8400-e29b-41d4-a716-446655440000',
                updated_by_id = '550e8400-e29b-41d4-a716-446655440000'
            )
        else:
            return EmbedderResponse(
                embedder_id = '550e8400-e29b-41d4-a716-446655440000',
                display_name = 'OpenAI Ada-2',
                provider_type = 'OPENAI',
                endpoint_url = 'https://api.openai.com/v1',
                api_path = '/embeddings',
                model_identifier = 'text-embedding-3-small',
                dimensionality = 1536,
                owner_id = '550e8400-e29b-41d4-a716-446655440000',
                created_at = 1617293472000,
                updated_at = 1617293472000,
                created_by_id = '550e8400-e29b-41d4-a716-446655440000',
                updated_by_id = '550e8400-e29b-41d4-a716-446655440000',
        )
        """

    def testEmbedderResponse(self):
        """Test EmbedderResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
