# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.models.ocr_input_format import OcrInputFormat

class TestOcrInputFormat(unittest.TestCase):
    """OcrInputFormat unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOcrInputFormat(self):
        """Test OcrInputFormat"""
        # inst = OcrInputFormat()

if __name__ == '__main__':
    unittest.main()
