# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from goodmem_client.models.processing_history import ProcessingHistory

class TestProcessingHistory(unittest.TestCase):
    """ProcessingHistory unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProcessingHistory:
        """Test ProcessingHistory
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProcessingHistory`
        """
        model = ProcessingHistory()
        if include_optional:
            return ProcessingHistory(
                latest_job = goodmem_client.models.background_job_summary.BackgroundJobSummary(
                    job_id = 42, 
                    job_type = 'document_processor', 
                    status = 'BACKGROUND_JOB_RUNNING', 
                    attempts = 1, 
                    max_attempts = 5, 
                    run_at = 1714713600000, 
                    lease_until = 1714713660000, 
                    locked_by = 'worker-1', 
                    last_error = 'Transient network failure', 
                    updated_at = 1714713615000, ),
                attempts = [
                    goodmem_client.models.background_job_attempt.BackgroundJobAttempt(
                        attempt_id = 101, 
                        job_id = 42, 
                        started_at = 1714713605000, 
                        finished_at = 1714713612000, 
                        ok = True, 
                        worker_id = 'worker-1', 
                        status_message = 'Uploading chunk 3/10', 
                        progress_current = 3, 
                        progress_total = 10, 
                        progress_unit = 'chunks', 
                        progress_updated_at = 1714713609000, 
                        error_message = 'S3 upload timed out', 
                        error_stacktrace = '', )
                    ]
            )
        else:
            return ProcessingHistory(
        )
        """

    def testProcessingHistory(self):
        """Test ProcessingHistory"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
